@@ -4,12 +4,14 @@ from decimal import Decimal
 
 from sql.aggregate import Sum
 
+from trytond.i18n import gettext
 from trytond.pool import PoolMeta, Pool
 from trytond.model import ModelView, Workflow, fields
+from trytond.model.exceptions import AccessError
 from trytond.pyson import Eval, Bool
 from trytond.transaction import Transaction
 
-__all__ = ['Production']
+from trytond.modules.product import round_price
 
 
 class Production(metaclass=PoolMeta):
@@ -29,22 +31,13 @@ class Production(metaclass=PoolMeta):
     works = fields.One2Many('production.work', 'production', 'Works',
         states={
             'readonly': Eval('state').in_(
-                ['request', 'draft', 'done', 'cancel']),
+                ['request', 'draft', 'done', 'cancelled']),
             },
         domain=[
             ('company', '=', Eval('company', -1)),
             ],
         depends=['state', 'company'])
 
-    @classmethod
-    def __setup__(cls):
-        super(Production, cls).__setup__()
-        cls._error_messages.update({
-                'do_finished_work': ('Production "%(production)s" '
-                    'can not be done '
-                    'because work "%(work)s" is not finished.'),
-                })
-
     def get_cost(self, name):
         pool = Pool()
         Work = pool.get('production.work')
@@ -69,8 +62,7 @@ class Production(metaclass=PoolMeta):
                 cycle_cost = Decimal(cycle_cost)
             cost += cycle_cost
 
-        digits = self.__class__.cost.digits
-        return cost.quantize(Decimal(str(10 ** -digits[1])))
+        return round_price(cost)
 
     @classmethod
     @ModelView.button
@@ -84,7 +76,7 @@ class Production(metaclass=PoolMeta):
 
     @classmethod
     @ModelView.button
-    @Workflow.transition('cancel')
+    @Workflow.transition('cancelled')
     def cancel(cls, productions):
         pool = Pool()
         Work = pool.get('production.work')
@@ -109,6 +101,7 @@ class Production(metaclass=PoolMeta):
         for production in draft_productions:
             works.extend(production.get_works(work_center_picker))
         Work.save(works)
+        Work.set_state([w for p in productions for w in p.works])
 
     def get_works(self, work_center_picker):
         if not self.routing:
@@ -136,10 +129,10 @@ class Production(metaclass=PoolMeta):
         for production in productions:
             for work in production.works:
                 if work.state != 'finished':
-                    cls.raise_user_error('do_finished_work', {
-                            'production': production.rec_name,
-                            'work': work.rec_name,
-                            })
+                    raise AccessError(
+                        gettext('production_work.msg_do_finished_work',
+                            production=production.rec_name,
+                            work=work.rec_name))
         super(Production, cls).done(productions)
         Work.set_state([w for p in productions for w in p.works])
 
