@@ -4,11 +4,13 @@ import unittest
 import doctest
 import trytond.tests.test_tryton
 from trytond.tests.test_tryton import ModuleTestCase
-from trytond.tests.test_tryton import doctest_setup, doctest_teardown
+from trytond.tests.test_tryton import doctest_teardown
 from trytond.tests.test_tryton import doctest_checker
 
+from trytond.modules.company.tests import CompanyTestMixin
 
-class ProductionWorkTestCase(ModuleTestCase):
+
+class ProductionWorkTestCase(CompanyTestMixin, ModuleTestCase):
     'Test Production Work module'
     module = 'production_work'
 
@@ -18,7 +20,7 @@ def suite():
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
             ProductionWorkTestCase))
     suite.addTests(doctest.DocFileSuite('scenario_production_work.rst',
-            setUp=doctest_setup, tearDown=doctest_teardown, encoding='utf-8',
+            tearDown=doctest_teardown, encoding='utf-8',
             checker=doctest_checker,
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
     return suite
